Documentation
¶
Overview ¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrInvalidIPAddress = errors.New("invalid ip address")
var ErrNotIPv4Address = errors.New("not an IPv4 addres")
var ErrNotIPv6Address = errors.New("not an IPv6 addres")
Functions ¶
func BigIntToIPv6 ¶
BigIntToIPv6 converts IP address of version 6 from big integer to net.IP representation.
func IPv6ToBigInt ¶
IPv6ToBigInt converts IP address of version 6 from net.IP to math big integer representation.
func IPv6ToInt ¶
IPv6ToInt converts IP address of version 6 from net.IP to uint64 array representation. Return value contains high integer value on the first place and low integer value on second place.
Types ¶
Click to show internal directories.
Click to hide internal directories.